@@ -27,6 +27,7 @@ describe 'vswitch::dpdk' do
         params.merge!(:socket_mem      => '')
         params.merge!(:memory_channels => '' )
         params.merge!(:pmd_core_list => '')
+        params.merge!(:disable_emc => false)
       end
       it 'configures dpdk options' do
         is_expected.to contain_vs_config('other_config:dpdk-init').with(
@@ -44,6 +45,7 @@ describe 'vswitch::dpdk' do
         is_expected.to contain_vs_config('other_config:dpdk-extra').with(
           :value => nil, :wait => false,
         )
+        is_expected.to_not contain_vs_config('other_config:emc-insert-inv-prob')
 
       end
     end
@@ -54,6 +56,7 @@ describe 'vswitch::dpdk' do
         params.merge!(:socket_mem      => '1024')
         params.merge!(:memory_channels => 2)
         params.merge!(:pmd_core_list => '22,23,24,25,66,67,68,69')
+        params.merge!(:disable_emc => true)
       end
       it 'configures dpdk options' do
         is_expected.to contain_vs_config('other_config:dpdk-init').with(
@@ -71,6 +74,9 @@ describe 'vswitch::dpdk' do
         is_expected.to contain_vs_config('other_config:dpdk-extra').with(
           :value => '-n 2', :wait => false,
         )
+        is_expected.to contain_vs_config('other_config:emc-insert-inv-prob').with(
+          :value  => '0', :notify => 'Service[openvswitch]', :wait => false,
+        )
       end
     end
 
